summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycalculator.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneycalculator.h')
-rw-r--r--kmymoney2/widgets/kmymoneycalculator.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmymoney2/widgets/kmymoneycalculator.h b/kmymoney2/widgets/kmymoneycalculator.h
index c015da3..3379bc3 100644
--- a/kmymoney2/widgets/kmymoneycalculator.h
+++ b/kmymoney2/widgets/kmymoneycalculator.h
@@ -222,7 +222,7 @@ private:
/* 0-9 are used by digits */
COMMA = 10,
/*
* make sure, that PLUS through ETQUAL remain in
* the order they are. Otherwise, check the calculation
* signal mapper
*/
@@ -230,7 +230,7 @@ private:
MINUS,
SLASH,
STAR,
- ETQUAL,
+ EQUAL,
PLUSMINUS,
PERCENT,
CLEAR,
@@ -222,7 +222,7 @@ private:
COMMA = 10,
/*
- * make sure, that PLUS through ETQUAL remain in
+ * make sure, that PLUS through EQUAL remain in
* the order they are. Otherwise, check the calculation
* signal mapper